<?php

namespace Bixo\Sanction\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Sanction\Models\Sanction;

class SanctionPolicy
{

    /**
     * Determine if the given user can view the sanction.
     *
     * @param UserPolicy $user
     * @param Sanction $sanction
     *
     * @return bool
     */
    public function view(UserPolicy $user, Sanction $sanction)
    {
        if ($user->canDo('sanction.sanction.view') && $user->isAdmin()) {
            return true;
        }

        return $sanction->user_id == user_id() && $sanction->user_type == user_type();
    }

    /**
     * Determine if the given user can create a sanction.
     *
     * @param UserPolicy $user
     * @param Sanction $sanction
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('sanction.sanction.create');
    }

    /**
     * Determine if the given user can update the given sanction.
     *
     * @param UserPolicy $user
     * @param Sanction $sanction
     *
     * @return bool
     */
    public function update(UserPolicy $user, Sanction $sanction)
    {
        if ($user->canDo('sanction.sanction.edit') && $user->isAdmin()) {
            return true;
        }

        return $sanction->user_id == user_id() && $sanction->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given sanction.
     *
     * @param UserPolicy $user
     * @param Sanction $sanction
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Sanction $sanction)
    {
        return $sanction->user_id == user_id() && $sanction->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given sanction.
     *
     * @param UserPolicy $user
     * @param Sanction $sanction
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Sanction $sanction)
    {
        if ($user->canDo('sanction.sanction.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given sanction.
     *
     * @param UserPolicy $user
     * @param Sanction $sanction
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Sanction $sanction)
    {
        if ($user->canDo('sanction.sanction.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
